$.jqplot.CanvasOverlay
Summary

$.jqplot.CanvasOverlay |
Properties |
objects |
name | Optional name for the overlay object.
show | true to show (draw), false to not draw.
lineWidth | Width of the line.
lineCap | Type of ending placed on the line [‘round’, ‘butt’, ‘square’]
color | color of the line
shadow | whether or not to draw a shadow on the line
shadowAngle | Shadow angle in degrees
shadowOffset | Shadow offset from line in pixels
shadowDepth | Number of times shadow is stroked, each stroke offset shadowOffset from the last.
shadowAlpha | Alpha channel transparency of shadow.
xaxis | X axis to use for positioning/scaling the line.
yaxis | Y axis to use for positioning/scaling the line.
showTooltip | Show a tooltip with data point values.
showTooltipPrecision | Controls how close to line cursor must be to show tooltip.
tooltipLocation | Where to position tooltip, ‘n’, ‘ne’, ‘e’, ‘se’, ‘s’, ‘sw’, ‘w’, ‘nw’
fadeTooltip | true = fade in/out tooltip, flase = show/hide tooltip
tooltipFadeSpeed | ‘slow’, ‘def’, ‘fast’, or number of milliseconds.
tooltipOffset | Pixel offset of tooltip from the highlight.
tooltipFormatString | Format string passed the x and y values of the cursor on the line.
Line | A straight line.
Properties |
start | [x, y] coordinates for the start of the line.
stop | [x, y] coordinates for the end of the line.
HorizontalLine | A straight horizontal line.
Properties |
y | y value to position the line
xmin | x value for the start of the line, null to scale to axis min.
xmax | x value for the end of the line, null to scale to axis max.
DashedHorizontalLine | A straight dashed horizontal line.
Properties |
dashPattern | Array of line, space settings in pixels.
VerticalLine | A straight vertical line.
DashedVerticalLine | A straight dashed vertical line.
Properties |
dashPattern | Array of line, space settings in pixels.

### Properties

### objects

> this.objects = []

### name

Optional name for the overlay object. Can be later used to retrieve the object by name.

### show

true to show (draw), false to not draw.

### lineWidth

Width of the line.

### lineCap

Type of ending placed on the line [‘round’, ‘butt’, ‘square’]

### color

color of the line

### shadow

whether or not to draw a shadow on the line

### shadowAngle

Shadow angle in degrees

### shadowOffset

Shadow offset from line in pixels

### shadowDepth

Number of times shadow is stroked, each stroke offset shadowOffset from the last.

### shadowAlpha

Alpha channel transparency of shadow. 0 = transparent.

### xaxis

X axis to use for positioning/scaling the line.

### yaxis

Y axis to use for positioning/scaling the line.

### showTooltip

Show a tooltip with data point values.

### showTooltipPrecision

Controls how close to line cursor must be to show tooltip. Higher number = closer to line, lower number = farther from line. 1.0 = cursor must be over line.

### tooltipLocation

Where to position tooltip, ‘n’, ‘ne’, ‘e’, ‘se’, ‘s’, ‘sw’, ‘w’, ‘nw’

### fadeTooltip

true = fade in/out tooltip, flase = show/hide tooltip

### tooltipFadeSpeed

’slow’, ‘def’, ‘fast’, or number of milliseconds.

### tooltipOffset

Pixel offset of tooltip from the highlight.

### tooltipFormatString

> tooltipFormatString: '%d, %d' }

Format string passed the x and y values of the cursor on the line. e.g., ‘Dogs: %.2f, Cats: %d’.

## Line

A straight line.

Summary

Properties |
start | [x, y] coordinates for the start of the line.
stop | [x, y] coordinates for the end of the line.

### Properties

### start

[x, y] coordinates for the start of the line.

### stop

> stop: [] }

[x, y] coordinates for the end of the line.

## HorizontalLine

A straight horizontal line.

Summary

Properties |
y | y value to position the line
xmin | x value for the start of the line, null to scale to axis min.
xmax | x value for the end of the line, null to scale to axis max.

### Properties

### y

y value to position the line

### xmin

x value for the start of the line, null to scale to axis min.

### xmax

x value for the end of the line, null to scale to axis max.

## DashedHorizontalLine

A straight dashed horizontal line.

Summary

Properties |
dashPattern | Array of line, space settings in pixels.

### Properties

### dashPattern

> dashPattern: [8,8] }

Array of line, space settings in pixels. Default is 8 pixel of line, 8 pixel of space. Note, limit to a 2 element array b/c of bug with higher order arrays.

## VerticalLine

A straight vertical line.

## DashedVerticalLine

A straight dashed vertical line.

Summary

Properties |
dashPattern | Array of line, space settings in pixels.

### Properties

### dashPattern

> dashPattern: [8,8] }

Array of line, space settings in pixels. Default is 8 pixel of line, 8 pixel of space. Note, limit to a 2 element array b/c of bug with higher order arrays.

> this.objects = []

> tooltipFormatString: '%d, %d' }

Format string passed the x and y values of the cursor on the line.

> stop: [] }

[x, y] coordinates for the end of the line.

> dashPattern: [8,8] }

Array of line, space settings in pixels.

> dashPattern: [8,8] }

Array of line, space settings in pixels.
Close